Skip to contents

An array of TermMapping objects, suitable for passing as the type argument to chat$chat_structured() when multiple concepts are to be mapped in a single call.

Usage

TermMappingTable

Format

An ellmer TypeArray whose items conform to TermMapping.