Skip to contents

utility to "clean" odd characters in text input that seem to increase risk of LLM failures

Usage

cleantxt(x)

Arguments

x

character(1) text from which non-alphabetic characters like brackets and parentheses are to be removed

Note

This is speculative; success rates appear to increase with no evident degradation of content interpretation.

Examples

cleantxt("RNA-seq (paired-end): analysis of #reads [v2]")
#> [1] "RNAseq pairedend) analysis of reads v2"