use Anh Vu's prompting to develop structured metadata about Bioconductor packages, targeting EDAM ontology and bio.tools schema
Source:R/curate_bioc.R
curate_bioc.Rduse Anh Vu's prompting to develop structured metadata about Bioconductor packages, targeting EDAM ontology and bio.tools schema
Usage
curate_bioc(
packageName = "chromVAR",
devurl =
"https://raw.githubusercontent.com/GreenleafLab/chromVAR/refs/heads/master/README.md",
model = "claude-sonnet-4-5",
provider = "anthropic"
)Arguments
- packageName
character(1) a Bioconductor software package name, its release landing page will be scraped
- devurl
character(1) a URL for doc originating from the developer
- model
character(1) model identifier for the selected provider; defaults to "claude-sonnet-4-5" (Anthropic)
- provider
character(1) LLM provider for the Python path; defaults to "anthropic". The value of the corresponding environment variable (see
llm_env_var) is used as the API key and the function stops with an informative error if the variable is not set.
Note
Schema completion is done with temperature set to 0.0; see edamize function for more flexibility.
Examples
if (interactive()) {
# ANTHROPIC_API_KEY must be set for the default provider
lk = curate_bioc()
str(lk)
}