Skip to contents

Summarise OLS4 MCP tools as a data frame

Usage

ols4_tool_table(tools)

Arguments

tools

list of ellmer tool objects as returned by ols4_mcp_tools.

Value

a data.frame with columns name and description, one row per tool.

Examples

if (interactive()) {
    tools <- ols4_mcp_tools()
    ols4_tool_table(tools)
}