full workflow to tag a bioconductor package and selected representative content with EDAM terms
Source:R/tag_bioc.R
tag_bioc.Rdfull workflow to tag a bioconductor package and selected representative content with EDAM terms
Usage
tag_bioc(
pkgname = "tximeta",
url =
"https://bioconductor.org/packages/release/bioc/vignettes/tximeta/inst/doc/tximeta.html",
provider = "anthropic"
)Arguments
- pkgname
character(1)
- url
URL for representative content, in html or pdf
- provider
character(1) LLM provider; see
llm_env_var. Defaults to "anthropic".
Examples
if (interactive()) {
ti = tag_bioc()
bs = tag_bioc(pkg="Biostrings",
url="https://bioconductor.org/packages/release/bioc/vignettes/Biostrings/inst/doc/Biostrings2Classes.pdf")
library(DT)
ndf = rbind(ti, bs)
datatable(ndf)
}