Create an ellmer chat object for a given LLM provider
Examples
if (interactive() && nchar(Sys.getenv("ANTHROPIC_API_KEY")) > 0) {
ch <- llm_chat("anthropic", model = "claude-haiku-4-5")
ch$chat("Name one EDAM topic term.")
}
Create an ellmer chat object for a given LLM provider
if (interactive() && nchar(Sys.getenv("ANTHROPIC_API_KEY")) > 0) {
ch <- llm_chat("anthropic", model = "claude-haiku-4-5")
ch$chat("Name one EDAM topic term.")
}