process the output of edamize followed by mkdf to create a data frame with components topic, operation, data, format, reflecting main elements of EDAM
Source:R/tag_bioc.R
toline.Rdprocess the output of edamize followed by mkdf to create a data frame with components topic, operation, data, format, reflecting main elements of EDAM
Examples
df <- data.frame(
uri = c("http://edamontology.org/topic_3308",
"http://edamontology.org/operation_2238",
"http://edamontology.org/data_3112",
"http://edamontology.org/format_3475"),
tm = c("Transcriptomics", "Statistical calculation",
"Gene expression matrix", "TSV"),
stringsAsFactors = FALSE)
toline(df)
#> topic operation
#> 1 Transcriptomics (3308) Statistical calculation (2238)
#> data format
#> 1 Gene expression matrix (3112) TSV (3475)